/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                SEXTO GRADO DE PRIMARIA (Excale 06)
/*
/*                          **** ESCUELAS ****
/*
/*                     Ciclo escolar evaluado: 2006 - 2007
/*_____________________________________________________________________________
/*
/*
/*            PROGRAMA PARA CONSTRUIR LA BASE DE DATOS DE ESCUELAS
/*                               EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte el archivo Excale06_2007_Escuelas.txt el cual est en
/*  formato ASCII a una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale06_2007_Escuelas.txt
/*         as como el archivo Excale06_2007_Escuelas.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale06_2007_Escuelas.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale06_2007_Escuelas.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 9 DE FEBRERO DE 2009
/*
/*  ****************************************************************************/


LIBNAME  INEE  "C:\***\";
FILENAME esc   "C:\***\Excale06_2007_Escuelas.TXT";

PROC FORMAT;
     VALUE id_entF
                       1         ="Aguascalientes"
                       2         ="Baja California"
                       3         ="Baja California Sur"
                       4         ="Campeche"
                       5         ="Coahuila"
                       6         ="Colima"
                       7         ="Chiapas"
                       8         ="Chihuahua"
                       9         ="Distrito Federal"
                       10        ="Durango"
                       11        ="Guanajuato"
                       12        ="Guerrero"
                       13        ="Hidalgo"
                       14        ="Jalisco"
                       15        ="Mxico"
                       16        ="Michoacn"
                       17        ="Morelos"
                       18        ="Nayarit"
                       19        ="Nuevo Len"
                       20        ="Oaxaca"
                       21        ="Puebla"
                       22        ="Quertaro"
                       23        ="Quintana Roo"
                       24        ="San Luis Potos"
                       25        ="Sinaloa"
                       26        ="Sonora"
                       27        ="Tabasco"
                       28        ="Tamaulipas"
                       29        ="Tlaxcala"
                       30        ="Veracruz"
                       31        ="Yucatn"
                       32        ="Zacatecas";
     VALUE id_turnF
                       1         ="Matutino"
                       2         ="Vespertino"
                       3         ="Nocturno"
                       4         ="Discontinuo"
                       5         ="Mixto";
     VALUE id_modF
                       1         ="Urbano Pblico"
                       2         ="Rural Pblico"
                       3         ="Educacin Indgena"
                       4         ="Cursos Comunitarios"
                       5         ="Privados";
     VALUE $modF
                       "UP"      ="Urbano Pblico"
                       "RP"      ="Rural Pblico"
                       "EI"      ="Educacin Indgena"
                       "CC"      ="Cursos Comunitarios"
                       "UPV"     ="Privados";
RUN;



DATA INEE.Excale06_2007_Escuelas;
   LENGTH
       proyecto           $10
       anio               4
       id_ent             3
       nom_ent            $19
       escuela            4
       id_turno           3
       turno_esc          $12
       entest             $6
       id_mod             3
       mod                $4
       nh                 8
       alu_esc            4
       alu_Shi            3
   ;

INFILE esc MISSOVER LINESIZE = 77;
   INPUT
        proyecto          1 - 10
        anio              11 - 14
        id_ent           15 - 16
        nom_ent          17 - 35
        escuela          36 - 39
        id_turno         40 - 40
        turno_esc        41 - 52
        entest           53 - 58
        id_mod           59 - 59
        mod              60 - 63
        nh               64 - 71
        alu_esc          72 - 75
        alu_Shi          76 - 77
   ;

   LABEL
       proyecto    = "Proyecto al que pertenece el estudio"
       anio        = "Ao del levantamiento de datos"
       id_ent      = "Entidad federativa (identificador numrico)"
       nom_ent     = "Entidad federativa"
       escuela     = "Identificador de la escuela"
       id_turno    = "Turno de la escuela (numrico)"
       turno_esc   = "Turno de la escuela"
       entest      = "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad-Densidad de poblacin)"
       id_mod      = "Estrato escolar o Modalidad educativa (identificador numrico)"
       mod         = "Estrato escolar o Modalidad educativa"
       nh          = "Cantidad de alumnos de 3o de preescolar en el estrato muestral ENTEST"
       alu_esc     = "Cantidad de alumnos de 3o de preescolar en la escuela"
       alu_Shi     = "Cantidad de alumnos evaluados en la escuela"
   ;

   FORMAT
        id_ent            id_entF.
        id_turno          id_turnF.
        id_mod            id_modF.
        mod               $modF.
   ;


/**************************************************************************
/*  Definicin de valores perdidos
/*************************************************************************/




RUN;



