/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                    SEXTO GRADO DE PRIMARIA (Excale 06)
/*
/*                              **** ESCUELAS ****
/*
/*                     Ciclo escolar evaluado: 2006 - 2007
/*_____________________________________________________________________________
/*
/*
/*            SINTAXIS PARA CONSTRUIR LA BASE DE DATOS DE ESCUELAS
/*                               EN FORMATO SPSS
/*_____________________________________________________________________________
/*
/*  La sintaxis convierte el archivo Excale06_2007_Escuelas.txt el cual est en
/*  formato ASCII a una base de datos en formato SPSS. La sintaxis realiza las
/*  siguientes tareas:
/*   - Lee las variables del archivo en formato ASCII
/*   - Etiqueta las variables as como sus valores
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale06_2007_Escuelas.txt
/*         as como el archivo Excale06_2007_Escuelas.SPS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la segunda y ltima lneas de los comandos de este archivo
/*         (Excale06_2007_Escuelas.SPS) para actualizar el nombre del directorio
/*         de trabajo.
/*      3) Ejecutar toda la sintaxis del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale06_2007_Escuelas.SAV
/*
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 9 DE FEBRERO DE 2009
/*
/*  ****************************************************************************/



SET DECIMAL=DOT.
                 /* Actualizar el nombre y directorio donde se ubica el archivo Excale06_2007_Escuelas.TXT*/
DATA LIST FILE = "C:\***\Excale06_2007_Escuelas.TXT"
       /
        proyecto      1 - 10  (a)
        ao          11 - 14
        id_ent       15 - 16
        nom_ent      17 - 35  (a)
        escuela      36 - 39
        id_turno     40 - 40
        turno_esc    41 - 52  (a)
        entest       53 - 58  (a)
        id_mod       59 - 59
        mod          60 - 63  (a)
        nh           64 - 71
        alu_esc      72 - 75
        alu_shi      76 - 77
.



/***********************************************************************
/* Etiqueta variables
/*
/**********************************************************************.

VARIABLE LABELS
      proyecto      "Proyecto al que pertenece el estudio"
      ao           "Ao del levantamiento de datos"
      id_ent        "Entidad federativa (identificador numrico)"
      nom_ent       "Entidad federativa"
      escuela       "Identificador de la escuela"
      id_turno      "Turno de la escuela (numrico)"
      turno_esc     "Turno de la escuela"
      entest        "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad-Densidad de poblacin)"
      id_mod        "Estrato escolar o Modalidad educativa (identificador numrico)"
      mod           "Estrato escolar o Modalidad educativa"
      nh            "Cantidad de alumnos de 6o de primaria en el estrato muestral ENTEST"
      alu_esc       "Cantidad de alumnos de 6o de primaria en la escuela"
      alu_Shi       "Cantidad de alumnos evaluados en la escuela"
.



/***********************************************************************
/* Etiquetas de valores.
/*
/**********************************************************************.

 VALUE LABELS
       id_ent
                 1      "Aguascalientes"
                 2      "Baja California"
                 3      "Baja California Sur"
                 4      "Campeche"
                 5      "Coahuila"
                 6      "Colima"
                 7      "Chiapas"
                 8      "Chihuahua"
                 9      "Distrito Federal"
                 10     "Durango"
                 11     "Guanajuato"
                 12     "Guerrero"
                 13     "Hidalgo"
                 14     "Jalisco"
                 15     "Mxico"
                 16     "Michoacn"
                 17     "Morelos"
                 18     "Nayarit"
                 19     "Nuevo Len"
                 20     "Oaxaca"
                 21     "Puebla"
                 22     "Quertaro"
                 23     "Quintana Roo"
                 24     "San Luis Potos"
                 25     "Sinaloa"
                 26     "Sonora"
                 27     "Tabasco"
                 28     "Tamaulipas"
                 29     "Tlaxcala"
                 30     "Veracruz"
                 31     "Yucatn"
                 32     "Zacatecas"/
     id_turno
                 1      "Matutino"
                 2      "Vespertino"
                 3      "Nocturno"
                 4      "Discontinuo"
                 5      "Mixto"/
     id_mod
                 1      "Urbano Pblico"
                 2      "Rural Pblico"
                 3      "Educacin Indgena"
                 4      "Cursos Comunitarios"
                 5      "Privados"/
     mod
                 "UP"   "Urbanas Pblicas"
                 "RP"   "Rurales Pblicas"
                 "EI"   "Educacin Indgena"
                 "CC"   "Cursos Comunitarios"
                 "UPV"  "Privadas"
.


             /* Actualizar el nombre y directorio donde se guarda el archivo  Excale06_2007_Escuelas.SAV */
SAVE OUTFILE="C:\***\Excale06_2007_Escuelas.SAV".

EXE.
